// src/index.ts
import { readFile } from "fs/promises";
import { compileTemplate } from "vue/compiler-sfc";
import { optimize } from "svgo";

// src/svgo-plugin-replace-fill.ts
var plugin = {
  name: "svgo-plugin-element-plus",
  type: "perItem",
  fn: (ast) => {
    if (ast.name == "path") {
      ast.attributes.fill = "currentColor";
    }
  }
};
var svgo_plugin_replace_fill_default = plugin;

// src/index.ts
var getDefaultSvgoOptions = (path) => {
  return {
    path,
    multipass: true,
    plugins: [
      "preset-default",
      "removeDimensions",
      {
        name: "removeAttrs",
        params: {
          attrs: "class"
        }
      },
      svgo_plugin_replace_fill_default
    ]
  };
};
function vpvepi(options = {}) {
  const svgRegex = /\.svg(\?(raw|component|url))?$/;
  const { svgoConfig, defaultQuery = "component" } = options;
  return {
    name: "vite-plugin-vue-element-plus",
    enforce: "pre",
    async load(id) {
      if (!id.match(svgRegex)) {
        return;
      }
      const [path, query] = id.split("?", 2);
      const queryType = query || defaultQuery;
      if (queryType === "url") {
        return;
      }
      let svgFileContent = "";
      try {
        svgFileContent = await readFile(path, "utf-8");
      } catch (e) {
        console.warn(`#vite-plugin-vue-element-plus-icon: [${path}] couldn't be read.`, e);
        return;
      }
      if (queryType !== "raw") {
        const result = optimize(
          svgFileContent,
          svgoConfig ? svgoConfig(path) : getDefaultSvgoOptions(path)
        );
        if (result.error) {
          console.warn(
            `#vite-plugin-vue-element-plus-icon: [${path}] couldn't be handled by svgo.`,
            result.error
          );
          return;
        }
        svgFileContent = result.data;
      }
      const { code } = compileTemplate({
        id: JSON.stringify(id),
        source: svgFileContent,
        filename: path,
        transformAssetUrls: false
      });
      return `${code} 
 export default { render }`;
    }
  };
}
export {
  vpvepi as default,
  getDefaultSvgoOptions
};
